<?php

/**
 * Register custom customizer panels, sections and settings.
 */

/**
 * We register our custom customizer by using the hook.
 *
 * @since  1.0.0
 */
function flashmagz_customizer_register() {

    // Stores all the controls that will be added
    $options = array();

    // Stores all the sections to be added
    $sections = array();

    // Stores all the panels to be added
    $panels = array();

    // Adds the sections to the $options array
    $options['sections'] = $sections;

    // ======= Start Customizer Panels/Sections/Settings ======= //

    // Theme prefix
    $prefix = 'flashmagz-';

    // Get all categories
    $categories = get_categories();

    // General Panels and Sections
    $general_panel = 'general';

    $panels[] = array(
        'id'       => $general_panel,
        'title'    => __('General', 'flashmagz'),
        'priority' => 10
    );

    // Favicon
    $section = $prefix . 'favicon-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Favicon', 'flashmagz'),
        'priority'    => 35,
        'panel'       => $general_panel
    );
    $options[$prefix . 'favicon'] = array(
        'id'           => $prefix . 'favicon',
        'label'        => __('Favicon', 'flashmagz'),
        'section'      => $section,
        'type'         => 'image',
        'default'      => '',
        'description'  => __('File must be <strong>.png</strong> or <strong>.ico</strong> format. Optimal dimensions: <strong>32px x 32px</strong>.', 'flashmagz'),
    );
    $options[$prefix . 'mobile-icon'] = array(
        'id'           => $prefix . 'mobile-icon',
        'label'        => __('Apple Touch Icon', 'flashmagz'),
        'section'      => $section,
        'type'         => 'image',
        'default'      => '',
        'description'  => __('File must be <strong>.png</strong> format. Optimal dimensions: <strong>152px x 152px</strong>.', 'flashmagz'),
    );

    // RSS
    $section = $prefix . 'rss-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('RSS', 'flashmagz'),
        'priority'    => 100,
        'panel'       => $general_panel,
        'description' => __('If you fill the custom rss url below, it will replace the default.', 'flashmagz'),
    );
    $options[$prefix . 'custom-rss'] = array(
        'id'           => $prefix . 'custom-rss',
        'label'        => __('Custom RSS URL (eg. Feedburner)', 'flashmagz'),
        'section'      => $section,
        'type'         => 'url',
        'default'      => ''
    );

    // Comment
    $section = $prefix . 'comment-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Comments', 'flashmagz'),
        'priority'    => 110,
        'panel'       => $general_panel,
    );
    $options[$prefix . 'page-comment'] = array(
        'id'           => $prefix . 'page-comment',
        'label'        => __('Page Comment', 'flashmagz'),
        'section'      => $section,
        'type'         => 'switch',
        'default'      => 1
    );

    // Footer Text
    $section = $prefix . 'footer-text-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Footer Text', 'flashmagz'),
        'priority'    => 120,
        'panel'       => $general_panel,
    );
    $options[$prefix . 'footer-text'] = array(
        'id'           => $prefix . 'footer-text',
        'label'        => '',
        'description'  => __('Customize the footer text.', 'flashmagz'),
        'section'      => $section,
        'type'         => 'textarea',
        'default'      => '&copy; Copyright ' . date('Y') . ' <a href="' . esc_url(home_url()) . '">' . esc_attr(get_bloginfo('name')) . '</a> &middot; Designed by <a href="http://www.happythemes.com/">Happy Themes</a>'
    );

    // Header Panels and Sections
    $header_panel = 'header';

    $panels[] = array(
        'id'       => $header_panel,
        'title'    => __('Header', 'flashmagz'),
        'priority' => 15
    );

    // Logo
    $section = $prefix . 'logo-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Logo', 'flashmagz'),
        'priority'    => 30,
        'panel'       => $header_panel
    );
    $options[$prefix . 'logo'] = array(
        'id'      => $prefix . 'logo',
        'label'   => __('Regular Logo', 'flashmagz'),
        'section' => $section,
        'type'    => 'image',
        'default' => ''
    );
    $options[$prefix . 'retina-logo'] = array(
        'id'           => $prefix . 'retina-logo',
        'label'        => __('Retina Logo', 'flashmagz'),
        'description'  => __('The Retina Logo should be twice the size of the Regular Logo.', 'flashmagz'),
        'section'      => $section,
        'type'         => 'image',
        'default'      => '',
    );

    // Search
    $section = $prefix . 'search-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Search', 'flashmagz'),
        'priority'    => 35,
        'panel'       => $header_panel
    );
    $options[$prefix . 'search'] = array(
        'id'          => $prefix . 'search',
        'label'       => '',
        'description' => __('Enable search form?', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );

    // Social header
    $section = $prefix . 'social-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Social', 'flashmagz'),
        'priority'    => 40,
        'panel'       => $header_panel
    );
    $options[$prefix . 'twitter'] = array(
        'id'      => $prefix . 'twitter',
        'label'   => __('Twitter URL', 'flashmagz'),
        'section' => $section,
        'type'    => 'url',
        'default' => ''
    );
    $options[$prefix . 'facebook'] = array(
        'id'      => $prefix . 'facebook',
        'label'   => __('Facebook URL', 'flashmagz'),
        'section' => $section,
        'type'    => 'url',
        'default' => ''
    );
    $options[$prefix . 'linkedin'] = array(
        'id'      => $prefix . 'linkedin',
        'label'   => __('Linkedin URL', 'flashmagz'),
        'section' => $section,
        'type'    => 'url',
        'default' => ''
    );
    $options[$prefix . 'instagram'] = array(
        'id'      => $prefix . 'instagram',
        'label'   => __('Instagram URL', 'flashmagz'),
        'section' => $section,
        'type'    => 'url',
        'default' => ''
    );
    $options[$prefix . 'youtube'] = array(
        'id'      => $prefix . 'youtube',
        'label'   => __('Youtube URL', 'flashmagz'),
        'section' => $section,
        'type'    => 'url',
        'default' => ''
    );
    $options[$prefix . 'rss'] = array(
        'id'      => $prefix . 'rss',
        'label'   => __('RSS URL', 'flashmagz'),
        'section' => $section,
        'type'    => 'url',
        'default' => ''
    );

    // Popup login
    $section = $prefix . 'login-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Login Link', 'flashmagz'),
        'description' => __('Please note, you\'d not see the login text if you logged in. Please log out and you will see the login link.', 'flashmagz'),
        'priority'    => 45,
        'panel'       => $header_panel
    );
    $options[$prefix . 'enable-login'] = array(
        'id'           => $prefix . 'enable-login',
        'label'        => __('Enable login link?', 'flashmagz'),
        'section'      => $section,
        'type'         => 'switch',
        'default'      => 1
    );
    $options[$prefix . 'text-login'] = array(
        'id'        => $prefix . 'text-login',
        'label'     => __('Login Text', 'flashmagz'),
        'section'   => $section,
        'type'      => 'text',
        'default'   => __('Login', 'flashmagz'),
        'transport' => 'postMessage'
    );

    // Colors Panel and Sections
    $color_panel = 'color';

    $panels[] = array(
        'id'       => $color_panel,
        'title'    => __('Color', 'flashmagz'),
        'priority' => 20
    );

    // Content colors
    $section = $prefix . 'content-bg-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Content', 'flashmagz'),
        'priority'    => 10,
        'panel'       => $color_panel
    );
    $options[$prefix . 'content-color'] = array(
        'id'          => $prefix . 'content-color',
        'label'       => __('Background color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#ffffff',
        'transport'   => 'postMessage'
    );
    $options[$prefix . 'content-border-color'] = array(
        'id'          => $prefix . 'content-border-color',
        'label'       => __('Border color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#e9e9e9',
        'transport'   => 'postMessage'
    );
    $options[$prefix . 'content-text-color'] = array(
        'id'          => $prefix . 'content-text-color',
        'label'       => __('Text color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#666666',
        'transport'   => 'postMessage'
    );
    $options[$prefix . 'content-heading-color'] = array(
        'id'          => $prefix . 'content-heading-color',
        'label'       => __('Heading color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#333333',
        'transport'   => 'postMessage'
    );
    $options[$prefix . 'content-link-color'] = array(
        'id'          => $prefix . 'content-link-color',
        'label'       => __('Link color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#0099e6',
        'transport'   => 'postMessage'
    );
    $options[$prefix . 'content-link-hover-color'] = array(
        'id'          => $prefix . 'content-link-hover-color',
        'label'       => __('Link hover color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#0099e6'
    );

    // Header background color
    $section = $prefix . 'header-bg-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Header', 'flashmagz'),
        'priority'    => 15,
        'panel'       => $color_panel
    );
    $options[$prefix . 'header-color'] = array(
        'id'          => $prefix . 'header-color',
        'label'       => __('Background color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#ffffff',
        'transport'   => 'postMessage'
    );
    $options[$prefix . 'site-title-color'] = array(
        'id'          => $prefix . 'site-title-color',
        'label'       => __('Site Title', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#323232',
        'transport'   => 'postMessage'
    );

    // Menu background color
    $section = $prefix . 'menu-bg-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Menu', 'flashmagz'),
        'priority'    => 20,
        'panel'       => $color_panel
    );
    $options[$prefix . 'menu-color'] = array(
        'id'          => $prefix . 'menu-color',
        'label'       => __('Background color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#141414',
        'transport'   => 'postMessage'
    );
    $options[$prefix . 'menu-border-color'] = array(
        'id'          => $prefix . 'menu-border-color',
        'label'       => __('Border color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#343434',
        'transport'   => 'postMessage'
    );
    $options[$prefix . 'menu-link-color'] = array(
        'id'          => $prefix . 'menu-link-color',
        'label'       => __('Link color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#ffffff',
        'transport'   => 'postMessage'
    );
    $options[$prefix . 'menu-link-login-color'] = array(
        'id'          => $prefix . 'menu-link-login-color',
        'label'       => __('Login/Profile Link color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#999999',
        'transport'   => 'postMessage'
    );

    // Category color
    $section = $prefix . 'category-color-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Category', 'flashmagz'),
        'priority'    => 25,
        'panel'       => $color_panel
    );

    foreach ($categories as $cat) {
        $options[$prefix . 'category-color-' . (int) $cat->term_id] = array(
            'id'          => $prefix . 'category-color-' . (int) $cat->term_id,
            'label'       => esc_attr($cat->name),
            'section'     => $section,
            'type'        => 'color',
            'default'     => '#1753e2'
        );
    }

    // Sidebar background and border color
    $section = $prefix . 'sidebar-bg-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Sidebar', 'flashmagz'),
        'priority'    => 30,
        'panel'       => $color_panel
    );
    $options[$prefix . 'sidebar-color'] = array(
        'id'          => $prefix . 'sidebar-color',
        'label'       => __('Background color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#ffffff',
        'transport'   => 'postMessage'
    );
    $options[$prefix . 'sidebar-border-color'] = array(
        'id'          => $prefix . 'sidebar-border-color',
        'label'       => __('Border color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#e9e9e9',
        'transport'   => 'postMessage'
    );
    $options[$prefix . 'sidebar-text-color'] = array(
        'id'          => $prefix . 'sidebar-text-color',
        'label'       => __('Text color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#666666',
        'transport'   => 'postMessage'
    );
    $options[$prefix . 'sidebar-text-title-color'] = array(
        'id'          => $prefix . 'sidebar-text-title-color',
        'label'       => __('Widget title color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#333333',
        'transport'   => 'postMessage'
    );
    $options[$prefix . 'sidebar-link-color'] = array(
        'id'          => $prefix . 'sidebar-link-color',
        'label'       => __('Link color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#666666',
        'transport'   => 'postMessage'
    );
    $options[$prefix . 'sidebar-link-hover-color'] = array(
        'id'          => $prefix . 'sidebar-link-hover-color',
        'label'       => __('Link hover color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#1753e2'
    );

    // Footer
    $section = $prefix . 'footer-bg-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Footer', 'flashmagz'),
        'priority'    => 35,
        'panel'       => $color_panel
    );
    $options[$prefix . 'footer-color'] = array(
        'id'          => $prefix . 'footer-color',
        'label'       => __('Background color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#141414',
        'transport'   => 'postMessage'
    );
    $options[$prefix . 'footer-border-color'] = array(
        'id'          => $prefix . 'footer-border-color',
        'label'       => __('Border color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#343434',
        'transport'   => 'postMessage'
    );
    $options[$prefix . 'footer-text-color'] = array(
        'id'          => $prefix . 'footer-text-color',
        'label'       => __('Text color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#999999',
        'transport'   => 'postMessage'
    );
    $options[$prefix . 'footer-text-title-color'] = array(
        'id'          => $prefix . 'footer-text-title-color',
        'label'       => __('Widget title color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#ffffff',
        'transport'   => 'postMessage'
    );
    $options[$prefix . 'footer-link-color'] = array(
        'id'          => $prefix . 'footer-link-color',
        'label'       => __('Link color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#999999',
        'transport'   => 'postMessage'
    );
    $options[$prefix . 'footer-link-hover-color'] = array(
        'id'          => $prefix . 'footer-link-hover-color',
        'label'       => __('Link hover color', 'flashmagz'),
        'section'     => $section,
        'type'        => 'color',
        'default'     => '#ffffff'
    );

    // Background Image Panels and Sections
    $bgimage_panel = 'bg_image';

    $panels[] = array(
        'id'       => $bgimage_panel,
        'title'    => __('Background Image', 'flashmagz'),
        'priority' => 25
    );

    // Typography Panel and Sections
    $typo_panel = 'typography';

    $panels[] = array(
        'id'       => $typo_panel,
        'title'    => __('Typography', 'flashmagz'),
        'priority' => 30
    );

    // Global typography
    $section = $prefix . 'global-typography';
    $font_choices = customizer_library_get_font_choices();

    $sections[] = array(
        'id'       => $section,
        'title'    => __('Global', 'flashmagz'),
        'priority' => 5,
        'panel'    => $typo_panel
    );
    $options[$prefix . 'text-font'] = array(
        'id'          => $prefix . 'text-font',
        'label'       => __('Text font', 'flashmagz'),
        'section'     => $section,
        'type'        => 'select2',
        'choices'     => $font_choices,
        'default'     => 'Roboto',
    );
    $options[$prefix . 'heading-font'] = array(
        'id'          => $prefix . 'heading-font',
        'label'       => __('Heading font', 'flashmagz'),
        'section'     => $section,
        'type'        => 'select2',
        'choices'     => $font_choices,
        'default'     => 'Roboto',
    );

    // Content Panel and Sections
    $content_panel = 'content-layout';

    $panels[] = array(
        'id'       => $content_panel,
        'title'    => __('Content Layout', 'flashmagz'),
        'priority' => 35
    );

    // Featured posts
    $section = $prefix . 'featured-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Featured Posts', 'flashmagz'),
        'description' => __('Featured posts are only displayed on home and category page.', 'flashmagz'),
        'priority'    => 5,
        'panel'       => $content_panel
    );
    $options[$prefix . 'featured-enable'] = array(
        'id'          => $prefix . 'featured-enable',
        'label'       => __('Show featured posts', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );
    $options[$prefix . 'featured-tag'] = array(
        'id'          => $prefix . 'featured-tag',
        'label'       => __('Select a tag', 'flashmagz'),
        'section'     => $section,
        'type'        => 'select2',
        'choices'     => flashmagz_tags_list()
    );

    // Posts
    $section = $prefix . 'posts-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Posts', 'flashmagz'),
        'description' => __('Posts is a single post page.', 'flashmagz'),
        'priority'    => 10,
        'panel'       => $content_panel
    );
    $options[$prefix . 'post-meta-group'] = array(
        'id'          => $prefix . 'post-meta-group',
        'label'       => __('Post Meta', 'flashmagz'),
        'section'     => $section,
        'type'        => 'group-title'
    );
    $options[$prefix . 'post-author-img'] = array(
        'id'          => $prefix . 'post-author-img',
        'label'       => __('Show post author image', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );
    $options[$prefix . 'post-author'] = array(
        'id'          => $prefix . 'post-author',
        'label'       => __('Show post author name', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );
    $options[$prefix . 'post-author-twitter'] = array(
        'id'          => $prefix . 'post-author-twitter',
        'label'       => __('Show post author twitter', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );
    $options[$prefix . 'post-date'] = array(
        'id'          => $prefix . 'post-date',
        'label'       => __('Show post date', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );
    $options[$prefix . 'post-share'] = array(
        'id'          => $prefix . 'post-share',
        'label'       => __('Show post share', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );
    $options[$prefix . 'post-date-group'] = array(
        'id'          => $prefix . 'post-date-group',
        'label'       => __('Post Date', 'flashmagz'),
        'section'     => $section,
        'type'        => 'group-title'
    );
    $options[$prefix . 'post-date-style'] = array(
        'id'          => $prefix . 'post-date-style',
        'label'       => __('Style', 'flashmagz'),
        'section'     => $section,
        'type'        => 'select',
        'default'     => 'absolute',
        'choices'     => array(
            'absolute' => __('Absolute (June 20, 2015 10:19 am)', 'flashmagz'),
            'relative' => __('Relative (1 week ago)', 'flashmagz')
        )
    );
    $options[$prefix . 'post-footer-group'] = array(
        'id'          => $prefix . 'post-footer-group',
        'label'       => __('Category and Tag', 'flashmagz'),
        'section'     => $section,
        'type'        => 'group-title'
    );
    $options[$prefix . 'post-cat'] = array(
        'id'          => $prefix . 'post-cat',
        'label'       => __('Show post categories', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );
    $options[$prefix . 'post-tag'] = array(
        'id'          => $prefix . 'post-tag',
        'label'       => __('Show post tags', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );
    $options[$prefix . 'related-posts-group'] = array(
        'id'          => $prefix . 'related-posts-group',
        'label'       => __('Related Posts', 'flashmagz'),
        'section'     => $section,
        'type'        => 'group-title'
    );
    $options[$prefix . 'related-posts'] = array(
        'id'          => $prefix . 'related-posts',
        'label'       => __('Show related posts', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );
    $options[$prefix . 'related-posts-img'] = array(
        'id'          => $prefix . 'related-posts-img',
        'label'       => __('Show related posts thumbnail', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );
    $options[$prefix . 'related-posts-excerpt'] = array(
        'id'          => $prefix . 'related-posts-excerpt',
        'label'       => __('Show related posts excerpt', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );

    // Page
    $section = $prefix . 'page-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Page', 'flashmagz'),
        'priority'    => 15,
        'panel'       => $content_panel
    );
    $options[$prefix . 'page-title'] = array(
        'id'          => $prefix . 'page-title',
        'label'       => __('Show page title', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );

    // Archive
    $section = $prefix . 'archive-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Archive', 'flashmagz'),
        'description' => __('Blog, date, month and year page.', 'flashmagz'),
        'priority'    => 20,
        'panel'       => $content_panel
    );
    $options[$prefix . 'archive-thumbnail'] = array(
        'id'          => $prefix . 'archive-thumbnail',
        'label'       => __('Show thumbnail', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );
    $options[$prefix . 'archive-excerpt'] = array(
        'id'          => $prefix . 'archive-excerpt',
        'label'       => __('Show excerpt', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );
    $options[$prefix . 'archive-excerpt-limit'] = array(
        'id'          => $prefix . 'archive-excerpt-limit',
        'label'       => __('Excerpt limit', 'flashmagz'),
        'section'     => $section,
        'type'        => 'number',
        'default'     => 15
    );
    $options[$prefix . 'archive-meta'] = array(
        'id'          => $prefix . 'archive-meta',
        'label'       => __('Show post meta', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );

    // Author page
    $section = $prefix . 'author-layout-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Author', 'flashmagz'),
        'description' => __('Please navigate the preview to the author page to see the changes.', 'flashmagz'),
        'priority'    => 25,
        'panel'       => $content_panel
    );
    $options[$prefix . 'author-thumbnail'] = array(
        'id'          => $prefix . 'author-thumbnail',
        'label'       => __('Show thumbnail', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );
    $options[$prefix . 'author-excerpt'] = array(
        'id'          => $prefix . 'author-excerpt',
        'label'       => __('Show excerpt', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );
    $options[$prefix . 'author-excerpt-limit'] = array(
        'id'          => $prefix . 'author-excerpt-limit',
        'label'       => __('Excerpt limit', 'flashmagz'),
        'section'     => $section,
        'type'        => 'number',
        'default'     => 15
    );
    $options[$prefix . 'author-meta'] = array(
        'id'          => $prefix . 'author-meta',
        'label'       => __('Show post meta', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );

    // Category
    $section = $prefix . 'category-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Category', 'flashmagz'),
        'description' => __('Please navigate the preview to the category page to see the changes.', 'flashmagz'),
        'priority'    => 30,
        'panel'       => $content_panel
    );
    $options[$prefix . 'cat-thumbnail'] = array(
        'id'          => $prefix . 'cat-thumbnail',
        'label'       => __('Show thumbnail', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );
    $options[$prefix . 'cat-excerpt'] = array(
        'id'          => $prefix . 'cat-excerpt',
        'label'       => __('Show excerpt', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );
    $options[$prefix . 'cat-excerpt-limit'] = array(
        'id'          => $prefix . 'cat-excerpt-limit',
        'label'       => __('Excerpt limit', 'flashmagz'),
        'section'     => $section,
        'type'        => 'number',
        'default'     => 15
    );
    $options[$prefix . 'cat-meta'] = array(
        'id'          => $prefix . 'cat-meta',
        'label'       => __('Show post meta', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );

    // Tag page
    $section = $prefix . 'tag-layout-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Tag', 'flashmagz'),
        'description' => __('Please navigate the preview to the tag page to see the changes.', 'flashmagz'),
        'priority'    => 35,
        'panel'       => $content_panel
    );
    $options[$prefix . 'tag-thumbnail'] = array(
        'id'          => $prefix . 'tag-thumbnail',
        'label'       => __('Show thumbnail', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );
    $options[$prefix . 'tag-excerpt'] = array(
        'id'          => $prefix . 'tag-excerpt',
        'label'       => __('Show excerpt', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );
    $options[$prefix . 'tag-excerpt-limit'] = array(
        'id'          => $prefix . 'tag-excerpt-limit',
        'label'       => __('Excerpt limit', 'flashmagz'),
        'section'     => $section,
        'type'        => 'number',
        'default'     => 15
    );
    $options[$prefix . 'tag-meta'] = array(
        'id'          => $prefix . 'tag-meta',
        'label'       => __('Show post meta', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );

    // Search page
    $section = $prefix . 'search-layout-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Search', 'flashmagz'),
        'description' => __('Please navigate the preview to the search page to see the changes.', 'flashmagz'),
        'priority'    => 40,
        'panel'       => $content_panel
    );
    $options[$prefix . 'search-thumbnail'] = array(
        'id'          => $prefix . 'search-thumbnail',
        'label'       => __('Show thumbnail', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );
    $options[$prefix . 'search-excerpt'] = array(
        'id'          => $prefix . 'search-excerpt',
        'label'       => __('Show excerpt', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );
    $options[$prefix . 'search-excerpt-limit'] = array(
        'id'          => $prefix . 'search-excerpt-limit',
        'label'       => __('Excerpt limit', 'flashmagz'),
        'section'     => $section,
        'type'        => 'number',
        'default'     => 15
    );
    $options[$prefix . 'search-meta'] = array(
        'id'          => $prefix . 'search-meta',
        'label'       => __('Show post meta', 'flashmagz'),
        'section'     => $section,
        'type'        => 'switch',
        'default'     => 1
    );

    // Advertisement Panel and Sections
    $ads_panel = 'advertisement';

    $panels[] = array(
        'id'       => $ads_panel,
        'title'    => __('Advertisement', 'flashmagz'),
        'priority' => 45
    );

    // Header ads
    $section = $prefix . 'header-ads-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Header', 'flashmagz'),
        'priority'    => 5,
        'panel'       => $ads_panel,
    );
    $options[$prefix . 'header-ads-image'] = array(
        'id'           => $prefix . 'header-ads-image',
        'label'        => __('Ads Image', 'flashmagz'),
        'description'  => __('Upload your ads image then put the url in the setting below.', 'flashmagz'),
        'section'      => $section,
        'type'         => 'image',
        'default'      => '',
    );
    $options[$prefix . 'header-ads-url'] = array(
        'id'           => $prefix . 'header-ads-url',
        'label'        => __('Ads URL', 'flashmagz'),
        'description'  => __('Put the ads url in the box below.', 'flashmagz'),
        'section'      => $section,
        'type'         => 'url',
        'default'      => ''
    );
    $options[$prefix . 'header-ads-custom'] = array(
        'id'                => $prefix . 'header-ads-custom',
        'label'             => __('Or', 'flashmagz'),
        'description'       => __('Pur you custom ads code (eg. adsense) in the box below.', 'flashmagz'),
        'section'           => $section,
        'type'              => 'textarea',
        'sanitize_callback' => 'flashmagz_textarea_stripslashes',
        'default'           => ''
    );

    // Posts ads
    $section = $prefix . 'posts-ads-section';

    $sections[] = array(
        'id'          => $section,
        'title'       => __('Posts', 'flashmagz'),
        'description' => __('Single post advertisement', 'flashmagz'),
        'priority'    => 10,
        'panel'       => $ads_panel,
    );
    $options[$prefix . 'post-ads-before'] = array(
        'id'          => $prefix . 'post-ads-before',
        'label'       => __('Ads Before Content', 'flashmagz'),
        'section'     => $section,
        'type'        => 'group-title'
    );
    $options[$prefix . 'post-ads-image-before'] = array(
        'id'           => $prefix . 'post-ads-image-before',
        'label'        => __('Ads Image', 'flashmagz'),
        'description'  => __('Upload your ads image then put the url in the setting below.', 'flashmagz'),
        'section'      => $section,
        'type'         => 'image',
        'default'      => '',
    );
    $options[$prefix . 'post-ads-url-before'] = array(
        'id'           => $prefix . 'post-ads-url-before',
        'label'        => __('Ads URL', 'flashmagz'),
        'description'  => __('Put the ads url in the box below.', 'flashmagz'),
        'section'      => $section,
        'type'         => 'url',
        'default'      => ''
    );
    $options[$prefix . 'post-ads-custom-before'] = array(
        'id'                => $prefix . 'post-ads-custom-before',
        'label'             => __('Or', 'flashmagz'),
        'description'       => __('Pur you custom ads code (eg. adsense) in the box below.', 'flashmagz'),
        'section'           => $section,
        'type'              => 'textarea',
        'sanitize_callback' => 'flashmagz_textarea_stripslashes',
        'default'           => ''
    );
    $options[$prefix . 'post-ads-after'] = array(
        'id'          => $prefix . 'post-ads-after',
        'label'       => __('Ads After Content', 'flashmagz'),
        'section'     => $section,
        'type'        => 'group-title'
    );
    $options[$prefix . 'post-ads-image-after'] = array(
        'id'           => $prefix . 'post-ads-image-after',
        'label'        => __('Ads Image', 'flashmagz'),
        'description'  => __('Upload your ads image then put the url in the setting below.', 'flashmagz'),
        'section'      => $section,
        'type'         => 'image',
        'default'      => '',
    );
    $options[$prefix . 'post-ads-url-after'] = array(
        'id'           => $prefix . 'post-ads-url-after',
        'label'        => __('Ads URL', 'flashmagz'),
        'description'  => __('Put the ads url in the box below.', 'flashmagz'),
        'section'      => $section,
        'type'         => 'url',
        'default'      => ''
    );
    $options[$prefix . 'post-ads-custom-after'] = array(
        'id'                => $prefix . 'post-ads-custom-after',
        'label'             => __('Or', 'flashmagz'),
        'description'       => __('Pur you custom ads code (eg. adsense) in the box below.', 'flashmagz'),
        'section'           => $section,
        'type'              => 'textarea',
        'sanitize_callback' => 'flashmagz_textarea_stripslashes',
        'default'           => ''
    );

    // Adds the sections to the $options array
    $options['sections'] = $sections;

    // Adds the panels to the $options array
    $options['panels'] = $panels;

    $customizer_library = Customizer_Library::Instance();
    $customizer_library->add_options($options);
}
add_action('init', 'flashmagz_customizer_register');
