<?php

/**
 * Custom template tags for this theme.
 * Eventually, some of the functionality here could be replaced by core features.
 */

if (!function_exists('flashmagz_site_branding')) :
    /**
     * Site branding for the site.
     *
     * Display site title by default, but user can change it with their custom logo.
     * They can upload it on Customizer page.
     *
     * @since  1.0.0
     */
    function flashmagz_site_branding() {

        // Theme prefix
        $prefix = 'flashmagz-';

        // Get the customizer value.
        $logo = flashmagz_mod($prefix . 'logo');

        // Check if logo available, then display it.
        if ($logo) :
            echo '<div id="logo" itemscope itemtype="http://schema.org/Brand">' . "\n";
            echo '<a href="' . esc_url(get_home_url()) . '" itemprop="url" rel="home">' . "\n";
            echo '<img itemprop="logo" src="' . esc_url($logo) . '" alt="' . esc_attr(get_bloginfo('name')) . '" />' . "\n";
            echo '</a>' . "\n";
            echo '</div>' . "\n";

        // If not, then display the Site Title and Site Description.
        else :
            echo '<div id="logo">' . "\n";
            echo '<h1 class="site-title" ' . hybrid_get_attr('site-title') . '><a href="' . esc_url(get_home_url()) . '" itemprop="url" rel="home"><span itemprop="headline">' . esc_attr(get_bloginfo('name')) . '</span></a></h1>' . "\n";
            echo '</div>' . "\n";
        endif;
    }
endif;

if (!function_exists('flashmagz_header_social')) :
    /**
     * Header social
     */
    function flashmagz_header_social() {

        // Theme prefix
        $prefix = 'flashmagz-';

        // Get the customizer data
        $tw        = flashmagz_mod($prefix . 'twitter');
        $fb        = flashmagz_mod($prefix . 'facebook');
        $instagram = flashmagz_mod($prefix . 'instagram');
        $linkedin  = flashmagz_mod($prefix . 'linkedin');
        $youtube   = flashmagz_mod($prefix . 'youtube');
        $rss       = flashmagz_mod($prefix . 'rss');

        // Display the data
        if ($tw || $fb || $linkedin || $instagram || $youtube || $rss) {
            echo '<div class="header-social">';
            if ($tw) {
                echo '<a href="' . esc_url($tw) . '"><i class="fa fa-twitter"></i></a>';
            }
            if ($fb) {
                echo '<a href="' . esc_url($fb) . '"><i class="fa fa-facebook"></i></a>';
            }
            if ($linkedin) {
                echo '<a href="' . esc_url($linkedin) . '"><i class="fa fa-linkedin"></i></a>';
            }
            if ($instagram) {
                echo '<a href="' . esc_url($instagram) . '"><i class="fa fa-instagram"></i></a>';
            }
            if ($youtube) {
                echo '<a href="' . esc_url($youtube) . '"><i class="fa fa-youtube"></i></a>';
            }
            if ($rss) {
                echo '<a href="' . esc_url($rss) . '"><i class="fa fa-rss"></i></a>';
            }
            echo '</div>';
        }
    }
endif;

if (!function_exists('flashmagz_login_link')) :
    /**
     * Login link in header
     */
    function flashmagz_login_link() {

        // Theme prefix
        $prefix = 'flashmagz-';

        // Get the customizer data
        $enable = flashmagz_mod($prefix . 'enable-login');
        $text   = flashmagz_mod($prefix . 'text-login');

        // Get current user name.
        $current_user = wp_get_current_user();

        // Check if user is logged in
        if (is_user_logged_in() && $enable == 1) {
            echo '<ul class="nav-right">';
            echo '<li><a id="modal_trigger" href="' . esc_url(admin_url()) . '"><i class="fa fa-user"></i> <span class="login-text">' . esc_attr($current_user->display_name) . '</span></a></li>';
            echo '</ul>';
        } elseif ($enable == 1) {
            echo '<ul class="nav-right">';
            echo '<li><a id="modal_trigger" href="#modal"><i class="fa fa-user"></i> <span class="login-text">' . esc_attr($text) . '</span></a></li>';
            echo '</ul>';
            flashmagz_login_popup(); // The popup content
        }
    }
endif;

if (!function_exists('flashmagz_login_popup')) :
    /**
     * Login popup content.
     */
    function flashmagz_login_popup() {
?>
        <div id="modal" class="popupContainer" style="display:none;">
            <header class="popupHeader">
                <span class="header_title"><?php _e('Login', 'flashmagz'); ?></span>
                <span class="modal_close"><i class="fa fa-times"></i></span>
            </header>

            <section class="popupBody">
                <div class="user_login">
                    <?php wp_login_form(); ?>
                    <div class="action_btns">
                        <a href="<?php echo esc_url(wp_lostpassword_url()); ?>"><?php _e('Forgot Password', 'flashmagz'); ?></a>
                    </div>
                </div>
            </section>
        </div>
    <?php
    }
endif;

if (!function_exists('flashmagz_header_ads')) :
    /**
     * Prints the advertisement data set in customizer.
     *
     * @since  1.0.0
     */
    function flashmagz_header_ads() {

        // Theme prefix
        $prefix = 'flashmagz-';

        // Get the ads data set in customizer
        $img    = flashmagz_mod($prefix . 'header-ads-image');
        $url    = flashmagz_mod($prefix . 'header-ads-url');
        $custom = flashmagz_mod($prefix . 'header-ads-custom');

        // Display the data
        if ($img || $url || $custom) {
            echo '<div class="header-ad">';
            if ($custom) {
                echo stripslashes($custom);
            } else {
                echo '<a href="' . esc_url($url) . '"><img src="' . esc_url($img) . '" /></a>';
            }
            echo '</div>';
        }
    }
endif;

if (!function_exists('flashmagz_posted_on')) :
    /**
     * Prints HTML with meta information for the current post-date/time and author.
     *
     * @since 1.0.0
     */
    function flashmagz_posted_on() {
    ?>
        <?php if ('post' == get_post_type() && !is_single()) : ?>
            <?php
            $category = get_the_category(get_the_ID());
            if ($category && flashmagz_categorized_blog()) :
            ?>
                <span class="entry-category" <?php hybrid_attr('entry-terms', 'category'); ?>>
                    <a href="<?php echo esc_url(get_category_link($category[0]->term_id)); ?>"><?php echo esc_attr($category[0]->name); ?></a>
                </span>
            <?php endif; // End if categories
            ?>

            <span class="sep">|</span>

        <?php endif; // End if 'post' == get_post_type()
        ?>

        <span class="entry-date">
            <time class="published" datetime="<?php echo esc_html(get_the_date('c')); ?>" <?php hybrid_attr('entry-published') ?>><?php echo esc_html(get_the_date()); ?></time>
        </span>
    <?php
    }
endif;

if (!function_exists('flashmagz_entry_meta')) :
    /**
     * Prints HTML with meta information for the current post-date/time and author.
     *
     * @since 1.0.0
     */
    function flashmagz_entry_meta() {

        // Theme prefix
        $prefix = 'flashmagz-';

        // Get the data set in customizer
        $avatar     = flashmagz_mod($prefix . 'post-author-img');
        $author     = flashmagz_mod($prefix . 'post-author');
        $twitter    = flashmagz_mod($prefix . 'post-author-twitter');
        $date       = flashmagz_mod($prefix . 'post-date');
        $date_style = flashmagz_mod($prefix . 'post-date-style');

        // Get the twitter username.
        $tw = get_the_author_meta('twitter');
    ?>
        <div class="entry-meta clearfix">

            <?php if ($avatar) { ?>
                <?php echo get_avatar(is_email(get_the_author_meta('user_email')), apply_filters('flashmagz_author_bio_avatar_size', 24), '', strip_tags(get_the_author())); ?>
            <?php } ?>

            <?php if ($author) { ?>
                <span class="entry-author author vcard" <?php hybrid_attr('entry-author') ?>>
                    <?php printf(__('by %s', 'flashmagz'), '<a class="url fn n" href="' . esc_url(get_author_posts_url(get_the_author_meta('ID'))) . '" itemprop="url"><span itemprop="name">' . esc_html(get_the_author()) . '</span></a>'); ?>
                </span>
                <span class="sep">/</span>
            <?php } ?>

            <?php if ($tw) { ?>
                <span class="entry-twitter"><a href="https://twitter.com/<?php echo esc_attr($tw) ?>" title="Follow on Twitter">@<?php echo esc_attr($tw); ?></a></span>
                <span class="sep">/</span>
            <?php } ?>

            <?php if ($date) { ?>
                <span class="entry-date">
                    <time class="published" datetime="<?php echo esc_html(get_the_date('c')); ?>" <?php hybrid_attr('entry-published') ?>>
                        <?php
                        if ($date_style == 'absolute') {
                            echo esc_html(get_the_date());
                        } else {
                            printf(__('%s ago', 'flashmagz'), human_time_diff(get_the_time('U'), current_time('timestamp')));
                        }
                        ?>
                    </time>
                </span>
            <?php } ?>

            <?php edit_post_link(__(' &middot; Edit', 'flashmagz'), '<span class="edit-link">', '</span>'); ?>

        </div>
    <?php
    }
endif;

if (!function_exists('flashmagz_entry_share')) :
    /**
     * Social share.
     *
     * @since 1.0.0
     */
    function flashmagz_entry_share() {
        global $post;

        // Theme prefix
        $prefix = 'flashmagz-';

        // Get the data set in customizer
        $share  = flashmagz_mod($prefix . 'post-share');

        if ($share == 0) {
            return;
        }
    ?>
        <div class="entry-share clearfix">
            <ul>
                <li class="twitter"><a href="https://twitter.com/intent/tweet?text=<?php echo esc_attr(get_the_title($post->ID)); ?>&amp;url=<?php echo urlencode(get_permalink($post->ID)); ?>" target="_blank"><i class="fa fa-twitter"></i>Twitter</a></li>
                <li class="facebook"><a href="https://www.facebook.com/sharer/sharer.php?u=<?php echo urlencode(get_permalink($post->ID)); ?>" target="_blank"><i class="fa fa-facebook"></i>Facebook</a></li>
                <li class="google-plus"><a href="https://plus.google.com/share?url=<?php echo urlencode(get_permalink($post->ID)); ?>" target="_blank"><i class="fa fa-google-plus"></i>Google+</a></li>
                <li class="linkedin"><a href="https://www.linkedin.com/shareArticle?mini=true&amp;url=<?php echo urlencode(get_permalink($post->ID)); ?>&amp;title=<?php echo esc_attr(get_the_title($post->ID)); ?>" target="_blank"><i class="fa fa-linkedin"></i>LinkedIn</a></li>
                <li class="pinterest"><a href="http://pinterest.com/pin/create/button/?url=<?php echo urlencode(get_permalink($post->ID)); ?>&amp;media=<?php echo urlencode(wp_get_attachment_url(get_post_thumbnail_id($post->ID))); ?>" target="_blank"><i class="fa fa-pinterest"></i>Pinterest</a></li>
            </ul>

            <?php flashmagz_comment_count(); // Get the comment count data.
            ?>
        </div>
    <?php
    }
endif;

if (!function_exists('flashmagz_comment_count')) :
    /**
     * Comment count
     *
     * @since  1.0.0
     */
    function flashmagz_comment_count() {
    ?>
        <?php if (!post_password_required() && (comments_open() || '0' != get_comments_number())) : ?>
            <div class="entry-comment">
                <?php comments_popup_link(__('<i class="fa fa-comment"></i> 0', 'flashmagz'), __('<i class="fa fa-comment"></i> 1', 'flashmagz'), __('<i class="fa fa-comment"></i> %', 'flashmagz')); ?>
            </div>
        <?php endif; ?>
    <?php
    }
endif;

if (!function_exists('flashmagz_entry_footer')) :
    /**
     * Post footer.
     *
     * @since  1.0.0
     */
    function flashmagz_entry_footer() {

        // Theme prefix
        $prefix = 'flashmagz-';

        // Get the data set in customizer
        $cat = flashmagz_mod($prefix . 'post-cat');
        $tag = flashmagz_mod($prefix . 'post-tag');

        if ($cat == 0 && $tag == 0) {
            return;
        }
    ?>
        <footer class="entry-footer">

            <?php if ('post' == get_post_type()) : // Hide category and tag text for pages on Search
            ?>
                <?php
                /* translators: used between list items, there is a space after the comma */
                $categories_list = get_the_category_list(__(', ', 'flashmagz'));
                if ($cat && $categories_list && flashmagz_categorized_blog()) :
                ?>
                    <span class="cat-links" <?php hybrid_attr('entry-terms', 'category'); ?>>
                        <?php printf(__('Categories: %1$s', 'flashmagz'), $categories_list); ?>
                    </span>
                <?php endif; // End if categories
                ?>

                <?php
                /* translators: used between list items, there is a space after the comma */
                $tags_list = get_the_tag_list('', __(', ', 'flashmagz'));
                if ($tag && $tags_list) :
                ?>
                    <span class="tags-links" <?php hybrid_attr('entry-terms', 'post_tag'); ?>>
                        <?php printf(__('Tags: %1$s', 'flashmagz'), $tags_list); ?>
                    </span>
                <?php endif; // End if $tags_list
                ?>
            <?php endif; // End if 'post' == get_post_type()
            ?>

        </footer>
        <?php
    }
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @since  1.0.0
 * @return bool
 */
function flashmagz_categorized_blog() {
    if (false === ($all_the_cool_cats = get_transient('flashmagz_categories'))) {
        // Create an array of all the categories that are attached to posts.
        $all_the_cool_cats = get_categories(array(
            'fields'     => 'ids',
            'hide_empty' => 1,

            // We only need to know if there is more than one category.
            'number'     => 2,
        ));

        // Count the number of categories that are attached to the posts.
        $all_the_cool_cats = count($all_the_cool_cats);

        set_transient('flashmagz_categories', $all_the_cool_cats);
    }

    if ($all_the_cool_cats > 1) {
        // This blog has more than 1 category so flashmagz_categorized_blog should return true.
        return true;
    } else {
        // This blog has only 1 category so flashmagz_categorized_blog should return false.
        return false;
    }
}

/**
 * Flush out the transients used in flashmagz_categorized_blog.
 *
 * @since 1.0.0
 */
function flashmagz_category_transient_flusher() {
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }
    // Like, beat it. Dig?
    delete_transient('flashmagz_categories');
}
add_action('edit_category', 'flashmagz_category_transient_flusher');
add_action('save_post',     'flashmagz_category_transient_flusher');

if (!function_exists('flashmagz_featured_content')) :
    /**
     * Featured content.
     *
     * @since  1.0.0
     */
    function flashmagz_featured_content() {
        global $cat;

        // Theme prefix.
        $prefix = 'flashmagz-';

        // Get the data set in customizer.
        $enable = flashmagz_mod($prefix . 'featured-enable');
        $tag    = flashmagz_mod($prefix . 'featured-tag');

        // Don't show featured content on single or paged page.
        if (is_single() || is_paged()) {
            return;
        }

        // Check if it enabled.
        if ($enable == 0) {
            return;
        }

        // Disable if user have not select a tag yet.
        if (empty($tag) || ($tag == 0)) {
            return;
        }

        // Posts query arguments.
        $args = array(
            'post_type'      => 'post',
            'posts_per_page' => 3,
            'tag_id'         => (int) $tag
        );

        // If on category archive page.
        if (is_category()) {
            $args['cat'] = $cat;
        }

        // Allow dev to filter the post arguments.
        $query = apply_filters('flashmagz_featured_content_args', $args);

        // The post query.
        $featured = new WP_Query($query);

        // Check if the post(s) exist.
        if ($featured->have_posts()) : ?>
            <?php $i = 0; ?>

            <div id="featured-content" class="featured">

                <?php while ($featured->have_posts()) : $featured->the_post(); ?>

                    <?php $category = get_the_category(); // Get post categories
                    ?>

                    <?php if (0 == $i) { ?>
                        <div class="featured-primary">
                            <a class="post-link" href="<?php the_permalink(); ?>">
                                <span class="gradient"></span>
                                <?php if (has_post_thumbnail()) : ?>
                                    <?php the_post_thumbnail('large', array('class' => 'entry-thumbnail', 'alt' => esc_attr(get_the_title()))); ?>
                                <?php endif; ?>
                                <div class="entry-header">
                                    <?php the_title('<h2 class="entry-title" ' . hybrid_get_attr('entry-title') . '>', '</h2>'); ?>
                                    <div class="entry-meta">
                                        <?php echo get_the_date(); ?>
                                    </div>
                                </div>
                                <?php echo '<span class="entry-category category-id-' . $category[0]->term_id . '">' . $category[0]->cat_name . '</span>'; ?>
                            </a>
                        </div>
                    <?php } else { ?>

                        <?php if (1 == $i) : ?><div class="featured-secondary"><?php endif; ?>

                            <div class="hentry">
                                <a class="post-link" href="<?php the_permalink(); ?>">
                                    <span class="gradient"></span>
                                    <?php if (has_post_thumbnail()) : ?>
                                        <?php the_post_thumbnail('large', array('class' => 'entry-thumbnail', 'alt' => esc_attr(get_the_title()))); ?>
                                    <?php endif; ?>
                                    <div class="entry-header">
                                        <?php the_title('<h2 class="entry-title" ' . hybrid_get_attr('entry-title') . '>', '</h2>'); ?>
                                        <div class="entry-meta">
                                            <?php echo get_the_date(); ?>
                                        </div>
                                    </div>
                                    <?php echo '<span class="entry-category category-id-' . $category[0]->term_id . '">' . $category[0]->cat_name . '</span>'; ?>
                                </a>
                            </div>

                            <?php if (2 == $i) : ?>
                            </div><!-- .featured-secondary --><?php endif; ?>

                    <?php } ?>

                <?php $i++;
                endwhile; ?>

            </div>

        <?php endif; // End check.

        // Restore original Post Data.
        wp_reset_postdata();
    }
endif;

if (!function_exists('flashmagz_related_posts')) :
    /**
     * Related posts.
     *
     * @since  1.0.0
     */
    function flashmagz_related_posts() {
        global $post;

        // Theme prefix
        $prefix = 'flashmagz-';

        // Get the data set in customizer
        $enable  = flashmagz_mod($prefix . 'related-posts');
        $img     = flashmagz_mod($prefix . 'related-posts-img');
        $excerpt = flashmagz_mod($prefix . 'related-posts-excerpt');

        // Disable if user choose it.
        if ($enable == 0) {
            return;
        }

        // Get the taxonomy terms of the current page for the specified taxonomy.
        $terms = wp_get_post_terms($post->ID, 'category', array('fields' => 'ids'));

        // Bail if the term empty.
        if (empty($terms)) {
            return;
        }

        // Posts query arguments.
        $query = array(
            'post__not_in' => array($post->ID),
            'tax_query'    => array(
                array(
                    'taxonomy' => 'category',
                    'field'    => 'id',
                    'terms'    => $terms,
                    'operator' => 'IN'
                )
            ),
            'posts_per_page' => 3,
            'post_type'      => 'post',
        );

        // Allow dev to filter the query.
        $args = apply_filters('flashmagz_related_posts_args', $query);

        // The post query
        $related = new WP_Query($args);

        if ($related->have_posts()) : ?>

            <div class="related-posts">
                <h3 class="block-title"><?php _e('Related Posts', 'flashmagz'); ?></h3>
                <ul class="clearfix">
                    <?php while ($related->have_posts()) : $related->the_post(); ?>
                        <li>
                            <?php if (has_post_thumbnail() && $img) : ?>
                                <a href="<?php the_permalink(); ?>"><?php the_post_thumbnail('flashmagz-thumbnail-one', array('class' => 'entry-thumbnail', 'alt' => esc_attr(get_the_title()))); ?></a>
                            <?php endif; ?>
                            <?php the_title(sprintf('<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url(get_permalink())), '</a></h2>'); ?>
                            <?php if ($excerpt) : ?>
                                <div class="entry-meta">
                                    <time class="entry-date published" datetime="<?php echo esc_attr(get_the_date('c')) ?>"><?php echo get_the_date(); ?></time>
                                </div>
                            <?php endif; ?>
                        </li>
                    <?php endwhile; ?>
                </ul>
            </div>

            <?php endif;

        // Restore original Post Data.
        wp_reset_postdata();
    }
endif;

if (!function_exists('flashmagz_comment')) :
    /**
     * Template for comments and pingbacks.
     *
     * Used as a callback by wp_list_comments() for displaying the comments.
     *
     * @since  1.0.0
     */
    function flashmagz_comment($comment, $args, $depth) {
        $GLOBALS['comment'] = $comment;
        switch ($comment->comment_type):
            case 'pingback':
            case 'trackback':
                // Display trackbacks differently than normal comments.
            ?>
                <li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>" <?php hybrid_attr('comment'); ?>>
                    <article id="comment-<?php comment_ID(); ?>" class="comment-container">
                        <p <?php hybrid_attr('comment-content'); ?>><?php _e('Pingback:', 'flashmagz'); ?> <span <?php hybrid_attr('comment-author'); ?>><span itemprop="name"><?php comment_author_link(); ?></span></span> <?php edit_comment_link(__('(Edit)', 'flashmagz'), '<span class="edit-link">', '</span>'); ?></p>
                    </article>
                <?php
                break;
            default:
                // Proceed with normal comments.
                global $post;
                ?>
                <li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>" <?php hybrid_attr('comment'); ?>>
                    <article id="comment-<?php comment_ID(); ?>" class="comment-wrapper">

                        <div class="comment-avatar">
                            <figure>
                                <?php echo get_avatar($comment, apply_filters('flashmagz_comment_avatar_size', 52)); ?>
                            </figure>
                        </div>

                        <div class="comment-detail">

                            <div class="comment-name number">
                                <span class="name" <?php hybrid_attr('comment-author'); ?>><span itemprop="name"><?php echo get_comment_author_link(); ?></span></span>
                                <?php
                                printf(
                                    '<span class="comment-date"><a href="%1$s" ' . hybrid_get_attr('comment-permalink') . '><time datetime="%2$s" ' . hybrid_get_attr('comment-published') . '>%3$s</time></a> %4$s</span>',
                                    esc_url(get_comment_link($comment->comment_ID)),
                                    get_comment_time('c'),
                                    /* translators: 1: date, 2: time */
                                    sprintf(__('%1$s at %2$s', 'flashmagz'), get_comment_date(), get_comment_time()),
                                    sprintf(__('%1$s&middot; Edit%2$s', 'flashmagz'), '<a href="' . get_edit_comment_link() . '" title="' . esc_attr__('Edit Comment', 'flashmagz') . '">', '</a>')
                                );
                                ?>
                            </div><!-- comment-head -->

                            <div class="comment-description comment-entry comment" <?php hybrid_attr('comment-content'); ?>>
                                <?php if ('0' == $comment->comment_approved) : ?>
                                    <p class="comment-awaiting-moderation"><?php _e('Your comment is awaiting moderation.', 'flashmagz'); ?></p>
                                <?php endif; ?>
                                <?php comment_text(); ?>
                                <span class="comment-reply">
                                    <?php comment_reply_link(array_merge($args, array('reply_text' => __('Reply <i class="fa fa-reply"></i>', 'flashmagz'), 'depth' => $depth, 'max_depth' => $args['max_depth']))); ?>
                                </span><!-- .reply -->
                            </div><!-- .comment-content -->

                        </div>

                    </article><!-- #comment-## -->
    <?php
                break;
        endswitch; // end comment_type check
    }
endif;

if (!function_exists('flashmagz_footer_text')) :
    /**
     * Footer Text
     */
    function flashmagz_footer_text() {

        // Theme prefix
        $prefix = 'flashmagz-';

        // Get the customizer data
        $footer_text = flashmagz_mod($prefix . 'footer-text');

        // Display the data
        echo stripslashes($footer_text);
    }
endif;
