<?php

/**
 * Three Columns widget.
 */
class Flashmagz_Three_Columns_Widget extends WP_Widget {

    /**
     * Sets up the widgets.
     *
     * @since 1.0.0
     */
    function __construct() {

        // Set up the widget options.
        $widget_options = array(
            'classname'   => 'widget-flashmagz-home-three-columns',
            'description' => __('Widget to display three columns custom posts list. Please only use it on home page/home sidebar.', 'flashmagz')
        );

        // Create the widget.
        parent::__construct(
            'flashmagz-home-three-columns',       // $this->id_base
            __('Home Three Columns', 'flashmagz'), // $this->name
            $widget_options                    // $this->widget_options
        );
    }

    /**
     * Outputs the widget based on the arguments input through the widget controls.
     *
     * @since 1.0.0
     */
    function widget($args, $instance) {
        extract($args);

        // Output the theme's $before_widget wrapper.
        echo $before_widget;

        // Theme prefix
        $prefix = 'flashmagz-';

        // Pull the selected category.
        $cat_id = isset($instance['cat']) ? absint($instance['cat']) : 0;

        // Get the category.
        $category = get_category($cat_id);

        // Get the category archive link.
        $cat_link = get_category_link($cat_id);

        // Posts query arguments.
        $args = array(
            'post_type'      => 'post',
            'posts_per_page' => (!empty($instance['limit'])) ? absint($instance['limit']) : 3
        );

        // Limit to category based on user selected tag.
        if (!$cat_id == 0) {
            $args['cat'] = $cat_id;
        }

        // Allow dev to filter the post arguments.
        $query = apply_filters('flashmagz_home_one_column_args', $args);

        // The post query.
        $posts = new WP_Query($query);

        if ($posts->have_posts()) : ?>

            <div class="widget-home-three-columns listing-3-col clearfix">

                <?php
                if (!empty($instance['title'])) {
                    echo '<h3 class="section-title">' . apply_filters('widget_title', $instance['title'], $instance, $this->id_base) . '</h3>';
                } elseif ($cat_id == 0) {
                    echo '<h3 class="section-title">' . __('Latest Posts', 'flashmagz') . '</h3>';
                } else {
                    echo '<h3 class="section-title"><a href="' . esc_url($cat_link) . '">' . esc_attr($category->name) . '</a></h3>';
                }
                ?>

                <ul class="clearfix">
                    <?php while ($posts->have_posts()) : $posts->the_post(); ?>
                        <li>
                            <a class="post-link clearfix" href="<?php the_permalink(); ?>">
                                <?php the_post_thumbnail('flashmagz-thumbnail-two', array('class' => 'entry-thumbnail', 'alt' => esc_attr(get_the_title()))); ?>
                                <?php the_title('<h2 class="entry-title" ' . hybrid_get_attr('entry-title') . '>', '</h2>'); ?>
                                <div class="entry-meta">
                                    <time class="entry-date published" datetime="<?php echo esc_attr(get_the_date('c')) ?>"><?php echo get_the_date(); ?></time>
                                </div>
                                <?php
                                $category = get_the_category();
                                echo '<span class="entry-category category-id-' . $category[0]->term_id . '">' . $category[0]->cat_name . '</span>';
                                ?>
                            </a>
                        </li>
                    <?php endwhile; ?>
                </ul>

            </div>

        <?php endif;

        // Restore original Post Data.
        wp_reset_postdata();

        // Close the theme's widget wrapper.
        echo $after_widget;
    }

    /**
     * Updates the widget control options for the particular instance of the widget.
     *
     * @since 1.0.0
     */
    function update($new_instance, $old_instance) {

        $instance = $new_instance;

        $instance['title'] = strip_tags($new_instance['title']);
        $instance['limit'] = (int) $new_instance['limit'];
        $instance['cat']   = (int) $new_instance['cat'];

        return $instance;
    }

    /**
     * Displays the widget control options in the Widgets admin screen.
     *
     * @since 1.0.0
     */
    function form($instance) {

        // Default value.
        $defaults = array(
            'title' => '',
            'limit' => 3,
            'cat'   => ''
        );

        $instance = wp_parse_args((array) $instance, $defaults);
        ?>

        <p>
            <label for="<?php echo $this->get_field_id('title'); ?>">
                <?php _e('Title:', 'flashmagz'); ?>
            </label>
            <input type="text" class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo esc_attr($instance['title']); ?>" />
        </p>

        <p>
            <label for="<?php echo $this->get_field_id('limit'); ?>">
                <?php _e('Number of posts to show', 'flashmagz'); ?>
            </label>
            <input class="widefat" id="<?php echo $this->get_field_id('limit'); ?>" name="<?php echo $this->get_field_name('limit'); ?>" type="number" step="1" min="0" value="<?php echo (int)($instance['limit']); ?>" />
        </p>

        <p>
            <label for="<?php echo $this->get_field_id('cat'); ?>"><?php _e('Choose Category', 'flashmagz'); ?></label>
            <select class="widefat" id="<?php echo $this->get_field_id('cat'); ?>" name="<?php echo $this->get_field_name('cat'); ?>" style="width:100%;">
                <?php $categories = get_terms('category'); ?>
                <option value="0"><?php _e('All categories &hellip;', 'flashmagz'); ?></option>
                <?php foreach ($categories as $category) { ?>
                    <option value="<?php echo esc_attr($category->term_id); ?>" <?php selected($instance['cat'], $category->term_id); ?>><?php echo esc_html($category->name); ?></option>
                <?php } ?>
            </select>
        </p>

<?php

    }
}
